Obtain channel information and data from given prefix and channel ID.
get_channel(x, channel_id)A list containing channel data and meta information, along with
the enclosing 'NSx' information; for invalid channel ID, this function
returns NULL
path prefix specified in import_nsp, or
'nev/nsx' object
integer channel number. Please be aware that channel number, channel ID, electrode ID refer to the same concept in 'Blackrock' 'NEV' specifications. Electrodes are not physical metals, they refer to channels for historical reasons.